MemoryStore

Struct MemoryStore 

pub struct MemoryStore { /* private fields */ }
Re-export of the in-memory object store.

Purpose

Stores raw, serialized version control objects in a HashMap residing in RAM, addressable by their Hash.

Examples

use libvctrl::{Hash, MemoryStore, ObjectStore};
use std::io::Read;

let mut store = MemoryStore::new();
let hash = Hash::from_bytes(&[0u8; 64]).unwrap();
store.put(&hash, b"data").unwrap();

let mut buf = Vec::new();
store.get(&hash).unwrap().read_to_end(&mut buf).unwrap();
assert_eq!(buf, b"data");

An in-memory implementation of the ObjectStore trait.

Purpose

Stores version control objects in a HashMap residing in RAM. This backend is primarily intended for testing and ephemeral operations.

Design rationale

This struct derives Default to allow easy instantiation via MemoryStore::default() or MemoryStore::new(). The internal HashMap is kept private to ensure that all modifications go through the ObjectStore trait implementation, preserving the integrity of the storage interface.

Examples

Storing and retrieving a blob via streaming:

use libvctrl_core::store::MemoryStore;
use libvctrl_handler::{Hash, ObjectStore};
use std::io::Read;

let mut store = MemoryStore::new();
let hash = Hash::from_bytes(&[0u8; 64]).unwrap();

store.put(&hash, b"my data").unwrap();
assert!(store.exists(&hash).unwrap());

let mut reader = store.get(&hash).unwrap();
let mut buf = Vec::new();
reader.read_to_end(&mut buf).unwrap();

assert_eq!(buf, b"my data");

Implementations

Source

impl MemoryStore

pub fn new() -> MemoryStore

Creates a new, empty MemoryStore.

Design rationale

This is a standard constructor that initializes an empty HashMap. It is functionally equivalent to MemoryStore::default().

Examples
use libvctrl_core::store::MemoryStore;
use libvctrl_handler::{Hash, ObjectStore};

let store = MemoryStore::new();
let hash = Hash::from_bytes(&[0u8; 64]).unwrap();
assert!(!store.exists(&hash).unwrap());